@@ -12,7 +12,7 @@ from astropy.modeling.models import Ellipse2D, Gaussian2D
 from astropy.convolution import Kernel2D
 from astropy.convolution.kernels import _round_up_to_odd_integer
 
-from .utils import deconvolve, convolve
+from .utils import deconvolve, convolve, RadioBeamDeprecationWarning
 
 # Conversion between a twod Gaussian FWHM**2 and effective area
 FWHM_TO_AREA = 2*np.pi/(8*np.log(2))
@@ -24,10 +24,11 @@ class NoBeamException(Exception):
 def _to_area(major,minor):
     return (major * minor * FWHM_TO_AREA).to(u.sr)
 
-unit_format = {u.deg: '\\circ',
+unit_format = {u.deg: r'\\circ',
                u.arcsec: "''",
                u.arcmin: "'"}
 
+
 class Beam(u.Quantity):
     """
     An object to handle single radio beams.
@@ -345,6 +346,12 @@ class Beam(u.Quantity):
 
     # Does division do the same? Or what? Doesn't have to be defined.
     def __sub__(self, other):
+        warnings.warn("Subtraction-as-deconvolution is deprecated. "
+                      "Use division instead.",
+                      RadioBeamDeprecationWarning)
+        return self.deconvolve(other)
+
+    def __truediv__(self, other):
         return self.deconvolve(other)
 
     def deconvolve(self, other, failure_returns_pointlike=False):
@@ -386,7 +393,11 @@ class Beam(u.Quantity):
         this_pa = self.pa.to(u.deg) % (180.0 * u.deg)
         other_pa = other.pa.to(u.deg) % (180.0 * u.deg)
 
-        equal_pa = True if np.abs(this_pa - other_pa) < atol_deg else False
+        if self.iscircular():
+            equal_pa = True
+        else:
+            equal_pa = True if np.abs(this_pa - other_pa) < atol_deg else False
+
         equal_maj = np.abs(self.major - other.major) < atol_deg
         equal_min = np.abs(self.minor - other.minor) < atol_deg
 
@@ -422,6 +433,12 @@ class Beam(u.Quantity):
         return ((self.major > 0) & (self.minor > 0) & np.isfinite(self.major) &
                 np.isfinite(self.minor) & np.isfinite(self.pa))
 
+    def iscircular(self, rtol=1e-6):
+
+        frac_diff = (self.major - self.minor).to(u.deg) / self.major.to(u.deg)
+
+        return frac_diff <= rtol
+
     def beam_projected_area(self, distance):
         """
         Return the beam area in pc^2 (or equivalent) given a distance
@@ -496,9 +513,11 @@ class Beam(u.Quantity):
         """
         from matplotlib.patches import Ellipse
         return Ellipse((xcen, ycen),
-                       width=self.major.to(u.deg).value / pixscale,
-                       height=self.minor.to(u.deg).value / pixscale,
-                       angle=self.pa.to(u.deg).value)
+                       width=(self.major.to(u.deg) / pixscale).to(u.dimensionless_unscaled).value,
+                       height=(self.minor.to(u.deg) / pixscale).to(u.dimensionless_unscaled).value,
+                       # PA is 90 deg offset from x-y axes by convention
+                       # (it is angle from NCP)
+                       angle=(self.pa+90*u.deg).to(u.deg).value)
 
     def as_kernel(self, pixscale, **kwargs):
         """
@@ -569,8 +588,13 @@ class Beam(u.Quantity):
         min_eff = gauss_to_top * self.minor.to(u.deg) / \
             (pixscale * SIGMA_TO_FWHM)
 
+        # position angle is defined as CCW from north
+        # "angle" is conventionally defined as CCW from "west".
+        # Therefore, add 90 degrees
+        angle = (90*u.deg+self.pa).to(u.radian).value,
+
         return EllipticalTophat2DKernel(maj_eff.value, min_eff.value,
-                                        self.pa.to(u.radian).value, **kwargs)
+                                        angle, **kwargs)
 
     def to_header_keywords(self):
         return {'BMAJ': self.major.to(u.deg).value,
@@ -578,7 +602,7 @@ class Beam(u.Quantity):
                 'BPA':  self.pa.to(u.deg).value,
                 }
 
-Beam.__doc__ = Beam.__doc__ + Beam.__new__.__doc__
+# Beam.__doc__ = Beam.__doc__ + Beam.__new__.__doc__
 
 def mywcs_to_platescale(mywcs):
     pix_area = wcs.utils.proj_plane_pixel_area(mywcs)
@@ -728,12 +752,13 @@ class EllipticalTophat2DKernel(Kernel2D):
 
         import matplotlib.pyplot as plt
         from radio_beam import EllipticalTophat2DKernel
-        gaussian_2D_kernel = EllipticalTophat2DKernel(10, 5, np.pi/4)
+        tophat_2D_kernel = EllipticalTophat2DKernel(10, 5, np.pi/4)
         plt.imshow(tophat_2D_kernel, interpolation='none', origin='lower')
         plt.xlabel('x [pixels]')
         plt.ylabel('y [pixels]')
         plt.colorbar()
         plt.show()
+
     """
 
     _is_bool = True
